<?php
    /**
     * customizer assets - theme Spiral Notebook
	 * Header Background Color setting.
	 *
	 * - Setting: Header Background Color
	 * - Control: WP_Customize_Color_Control
	 * - Sanitization: esc_attr
	 *
	 * Uses a color wheel to configure the Header Background Color setting.
	 *
	 * https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
	 */


function spiral_notebook_register_theme_customizer($wp_customize)
{
    $wp_customize->add_section('spiral_notebook_header_background_color_section', array(
            'title'             => esc_html__( 'Spiral Background Colors', 'spiral-notebook' ),
            'priority'          => 45
        ));

    /*
     * WP_Customize_Manager/add_setting
    */
	$wp_customize->add_setting(	'spiral_notebook_header_background_color_setting', array(
            'type'              => 'theme_mod',
            'default'           => 'ffffff',
			'sanitize_callback'	=> 'sanitize_hex_color',
			'transport'			=> 'refresh'
		)
	);

	$wp_customize->add_setting(	'spiral_notebook_footer_text_color_setting', array(
            'type'              => 'theme_mod',
            'default'           => '3377bb',
			'sanitize_callback'	=> 'sanitize_hex_color',
			'transport'			=> 'refresh'
		)
	);

    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'header_background_color', array(
				'settings'		=> 'spiral_notebook_header_background_color_setting',
				'section'		=> 'spiral_notebook_header_background_color_section',
				'label'			=> esc_html__( 'Header and Footer Background Color', 'spiral-notebook' ),
				'description'	=> esc_html__(
                    'Select the background color of the spiral rings area. Also appliies to the Footer background color.', 'spiral-notebook' ),
			)
		)
    );

    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'footer_text_color', array(
				'settings'		=> 'spiral_notebook_footer_text_color_setting',
				'section'		=> 'spiral_notebook_header_background_color_section',
				'label'			=> esc_html__( 'Footer Text Color', 'spiral-notebook' ),
				'description'	=> esc_html__(
                    'Select the contrast color to text in the footer of theme.',
                    'spiral-notebook' ),
			)
		)
    );

}
add_action('customize_register', 'spiral_notebook_register_theme_customizer');



/**
 * Writes the Header Background related controls' values outputed to the 'head' of the document
 * by reading the value(s) from the theme mod value in the options table.
 */
function spiral_notebook_customizer_css() {
    if ( get_theme_mods() )
    {
    echo '<style type="text/css">';

        if ( get_theme_mod( 'spiral_notebook_header_background_color_setting' ) ) :
             $spiralheader = get_theme_mod( 'spiral_notebook_header_background_color_setting' );
			 $spirhead = '.site-header, .footer-footer {background: ' . sanitize_hex_color($spiralheader) . ';}';
                echo esc_attr( $spirhead );
        endif;
        if ( get_theme_mod( 'spiral_notebook_footer_text_color_setting' ) ) :
            $spiralfooter = get_theme_mod( 'spiral_notebook_footer_text_color_setting' );
                $spirfoot = '.footer-footer a, .footer-footer ul li, .footer-footer p,
                            .footer-footer caption {color: ' . sanitize_hex_color($spiralfooter) . ';}';
                echo esc_attr( $spirfoot );
        endif;

    echo '</style>';
    }
}
add_action( 'wp_head', 'spiral_notebook_customizer_css'); 
